spacepy.toolbox.mlt2rad — SpacePy v0.1.5 Manual

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »
- toolbox - Toolbox of various functions and generic utilities »

# spacepy.toolbox.mlt2rad

`spacepy.toolbox.` `mlt2rad`(mlt, midnight=False)

  Convert mlt values to radians for polar plotting transform mlt angles to radians from -pi to pi referenced from noon by default

  Parameters: | mlt : numpy array array of mlt values midnight : boolean (optional) reference to midnight instead of noon
  Returns: | out : numpy array array of radians

  See also

  `rad2mlt`

  Examples

      >>> from numpy import array
      >>> mlt2rad(array([3,6,9,14,22]))
      array([-2.35619449, -1.57079633, -0.78539816,  0.52359878,  2.61799388])

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »
- toolbox - Toolbox of various functions and generic utilities »